{% extends "admin/base_site.html" %}
{% load i18n static admin_urls admin_modify admin_kubi_tags %}

{% block extrastyle %}{{ block.super }}<link rel="stylesheet" type="text/css" href="{% static "admin/css/forms.css" %}" />{% endblock %}
{% block bodyclass %}{{ block.super }} {{ opts.app_label }}-{{ opts.object_name.lower }} change-form{% endblock %}


{% if not is_popup %}
  {% block breadcrumbs %}
    {% spaceless %}
      <nav class="breadcrumb">
        {% breadcrumbs_icon opts %}
        <a class="breadcrumb-item" href="{% url opts|admin_urlname:'changelist' %}">{{ opts.verbose_name_plural|capfirst }}</a>
        <span class="breadcrumb-item active">{% block breadcrumbs_last %}{% endblock %}</span>
      </nav>
    {% endspaceless %}
  {% endblock %}
{% endif %}
